@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.text.resources.cldr.ext;
@@ -66,6 +74,20 @@ import java.util.ListResourceBundle;
 public class FormatData_te extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
+            "AM",
+            "PM",
+            "అర్ధరాత్రి",
+            "",
+            "ఉదయం",
+            "",
+            "మధ్యాహ్నం",
+            "",
+            "సాయంత్రం",
+            "",
+            "రాత్రి",
+            "",
+        };
         final String metaValue_generic_DateFormatItem_Gy = "y G";
         final String[] metaValue_MonthNames = new String[] {
             "జనవరి",
@@ -151,34 +173,6 @@ public class FormatData_te extends ListResourceBundle {
             "త్రై3",
             "త్రై4",
         };
-        final String[] metaValue_generic_abbreviated_AmPmMarkers = new String[] {
-            "AM",
-            "PM",
-            "అర్ధరాత్రి",
-            "",
-            "ఉదయం",
-            "",
-            "మధ్యాహ్నం",
-            "",
-            "సాయంత్రం",
-            "",
-            "రాత్రి",
-            "",
-        };
-        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
-            "ఉ",
-            "సా",
-            "అర్ధరాత్రి",
-            "",
-            "ఉదయం",
-            "",
-            "మధ్యాహ్నం",
-            "",
-            "సాయంత్రం",
-            "",
-            "రాత్రి",
-            "",
-        };
         final String[] metaValue_java_time_long_Eras = new String[] {
             "క్రీస్తు పూర్వం",
             "క్రీస్తు శకం",
@@ -204,8 +198,11 @@ public class FormatData_te extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_yQQQ = "QQQ y";
         final String metaValue_generic_DateFormatItem_MMMMd = "d MMMM";
         final String metaValue_generic_DateFormatItem_MMMEd = "d MMM, E";
+        final String metaValue_generic_DateFormatItem_GyMEd = "G d/M/y, E";
+        final String metaValue_generic_DateFormatItem_EBh = "E B h";
         final String metaValue_generic_DateFormatItem_MMMd = "d MMM";
         final String metaValue_generic_DateFormatItem_MMMMW = "MMMMలో Wవ వారం";
+        final String metaValue_generic_DateFormatItem_GyM = "G M/y";
         final String metaValue_generic_DateFormatItem_GyMMM = "G MMM y";
         final String metaValue_generic_DateFormatItem_yMMMEd = "d MMM, y, E";
         final String metaValue_generic_DateFormatItem_yMEd = "d/M/y, E";
@@ -234,7 +231,7 @@ public class FormatData_te extends ListResourceBundle {
         };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
             "R.O.C. పూర్వం",
-            "R.O.C.",
+            "ROC",
         };
         final String metaValue_calendarname_gregorian = "గ్రేగోరియన్ క్యాలెండర్";
         final String[] metaValue_ListPatterns_standard = new String[] {
@@ -265,7 +262,7 @@ public class FormatData_te extends ListResourceBundle {
             { "generic.QuarterNames", metaValue_generic_QuarterNames },
             { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
@@ -281,11 +278,14 @@ public class FormatData_te extends ListResourceBundle {
             { "generic.DateFormatItem.EBhm", "B E h:mm" },
             { "generic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "generic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "generic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
             { "generic.DateFormatItem.Bh", "B h" },
+            { "generic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "generic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
             { "generic.DateFormatItem.yyyy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.y", metaValue_generic_DateFormatItem_Gy },
+            { "generic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -326,9 +326,9 @@ public class FormatData_te extends ListResourceBundle {
             { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.long.Eras", metaValue_java_time_long_Eras },
             { "long.Eras", metaValue_java_time_long_Eras },
             { "java.time.Eras", metaValue_java_time_Eras },
@@ -343,7 +343,7 @@ public class FormatData_te extends ListResourceBundle {
             { "field.dayperiod", "AM/PM" },
             { "field.hour", "గంట" },
             { "timezone.regionFormat", "{0} సమయం" },
-            { "timezone.regionFormat.daylight", "{0} పగటి వెలుతురు సమయం" },
+            { "timezone.regionFormat.daylight", "{0} పగటి కాంతి సమయం" },
             { "timezone.regionFormat.standard", "{0} ప్రామాణిక సమయం" },
             { "field.minute", "నిమిషము" },
             { "field.second", "సెకను" },
@@ -365,8 +365,11 @@ public class FormatData_te extends ListResourceBundle {
             { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -387,9 +390,9 @@ public class FormatData_te extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "buddhist.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
@@ -398,8 +401,11 @@ public class FormatData_te extends ListResourceBundle {
             { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "buddhist.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "buddhist.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "buddhist.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "buddhist.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "buddhist.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "buddhist.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "buddhist.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "buddhist.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -420,9 +426,8 @@ public class FormatData_te extends ListResourceBundle {
             { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "japanese.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
-            { "japanese.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "japanese.DatePatterns",
@@ -438,8 +443,11 @@ public class FormatData_te extends ListResourceBundle {
             { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "japanese.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "japanese.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "japanese.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "japanese.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "japanese.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "japanese.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -461,8 +469,7 @@ public class FormatData_te extends ListResourceBundle {
             { "roc.DayNarrows", metaValue_generic_DayNarrows },
             { "roc.QuarterNames", metaValue_generic_QuarterNames },
             { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "roc.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -477,8 +484,11 @@ public class FormatData_te extends ListResourceBundle {
             { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "roc.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "roc.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "roc.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "roc.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "roc.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "roc.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "roc.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -514,8 +524,7 @@ public class FormatData_te extends ListResourceBundle {
             { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "islamic.DatePatterns", metaValue_generic_DatePatterns },
@@ -524,8 +533,11 @@ public class FormatData_te extends ListResourceBundle {
             { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "islamic.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -545,8 +557,11 @@ public class FormatData_te extends ListResourceBundle {
             { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-civil.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-civil.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-civil.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "islamic-civil.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-civil.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-civil.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-civil.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -566,8 +581,11 @@ public class FormatData_te extends ListResourceBundle {
             { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "islamic-umalqura.DateFormatItem.MMMMd", metaValue_generic_DateFormatItem_MMMMd },
             { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_generic_DateFormatItem_MMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMEd", metaValue_generic_DateFormatItem_GyMEd },
+            { "islamic-umalqura.DateFormatItem.EBh", metaValue_generic_DateFormatItem_EBh },
             { "islamic-umalqura.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMd },
             { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-umalqura.DateFormatItem.GyM", metaValue_generic_DateFormatItem_GyM },
             { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
@@ -585,7 +603,7 @@ public class FormatData_te extends ListResourceBundle {
             { "calendarname.islamic-civil", "ఇస్లామిక్-సివిల్ క్యాలెండర్" },
             { "calendarname.islamic", "ఇస్లామిక్ క్యాలెండర్" },
             { "calendarname.buddhist", "బుద్ధుల క్యాలెండర్‌" },
-            { "calendarname.japanese", "జపానీయుల క్యాలెండర్" },
+            { "calendarname.japanese", "జపనీస్ క్యాలెండర్" },
             { "calendarname.roc", "మింగ్యూ క్యాలెండర్" },
             { "calendarname.islamic-umalqura", "ఇస్లామిక్ క్యాలెండర్ (ఉమ్ అల్-ఖురా)" },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
